Low-level LAPACK functions (scipy.linalg.lapack)#
This module contains low-level functions from the LAPACK library.
Added in version 0.12.0.
Note
The common overwrite_<> option in many routines, allows the
input arrays to be overwritten to avoid extra memory allocation.
However this requires the array to satisfy two conditions
which are memory order and the data type to match exactly the
order and the type expected by the routine.
As an example, if you pass a double precision float array to any
S.... routine which expects single precision arguments, f2py
will create an intermediate array to match the argument types and
overwriting will be performed on that intermediate array.
Similarly, if a C-contiguous array is passed, f2py will pass a FORTRAN-contiguous array internally. Please make sure that these details are satisfied. More information can be found in the f2py documentation.
Warning
These functions do little to no error checking.
It is possible to cause crashes by misusing them,
so prefer using the higher-level routines in scipy.linalg.
Note
Prefer using get_lapack_funcs to importing the bare functions directly.
If you do, for example, from scipy.linalg.lapack import dsysv, the dsysv
function may be either LP64 or ILP64, depending on how SciPy is built.
The following is more robust:
>>> from scipy.linalg.lapack import get_lapack_funcs
>>> dsysv = get_lapack_funcs('sysv', dtype='float64', ilp64='preferred')
>>> dsysv.int_dtype
dtype('int32') # may vary
Finding functions#
|
Return available LAPACK function objects from names. |
All functions#
|
Estimate the reciprocal condition number of a banded matrix from its |
|
Estimate the reciprocal condition number of a banded matrix from its |
|
Estimate the reciprocal condition number of a banded matrix from its |
|
Estimate the reciprocal condition number of a banded matrix from its |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Compute the LU factorization of a banded matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a banded matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a banded matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a banded matrix with partial pivoting (LAPACK |
|
Solve a banded system using the factorization from |
|
Solve a banded system using the factorization from |
|
Solve a banded system using the factorization from |
|
Solve a banded system using the factorization from |
|
Balance a general matrix to improve eigenvalue accuracy (LAPACK |
|
Balance a general matrix to improve eigenvalue accuracy (LAPACK |
|
Balance a general matrix to improve eigenvalue accuracy (LAPACK |
|
Balance a general matrix to improve eigenvalue accuracy (LAPACK |
|
Estimate the reciprocal condition number of a factorized matrix (LAPACK |
|
Estimate the reciprocal condition number of a factorized matrix (LAPACK |
|
Estimate the reciprocal condition number of a factorized matrix (LAPACK |
|
Estimate the reciprocal condition number of a factorized matrix (LAPACK |
|
Compute row and column scale factors that equilibrate a matrix (LAPACK |
|
Compute row and column scale factors that equilibrate a matrix (LAPACK |
|
Compute row and column scale factors that equilibrate a matrix (LAPACK |
|
Compute row and column scale factors that equilibrate a matrix (LAPACK |
|
Compute equilibration factors restricted to powers of the radix (LAPACK |
|
Compute equilibration factors restricted to powers of the radix (LAPACK |
|
Compute equilibration factors restricted to powers of the radix (LAPACK |
|
Compute equilibration factors restricted to powers of the radix (LAPACK |
|
Compute the Schur factorization of a general matrix (LAPACK |
|
Compute the Schur factorization of a general matrix (LAPACK |
|
Compute the Schur factorization of a general matrix (LAPACK |
|
Compute the Schur factorization of a general matrix (LAPACK |
|
Compute the eigenvalues and eigenvectors of a general matrix (LAPACK |
|
Compute the eigenvalues and eigenvectors of a general matrix (LAPACK |
|
Compute the eigenvalues and eigenvectors of a general matrix (LAPACK |
|
Compute the eigenvalues and eigenvectors of a general matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Reduce a matrix to upper Hessenberg form (LAPACK |
|
Reduce a matrix to upper Hessenberg form (LAPACK |
|
Reduce a matrix to upper Hessenberg form (LAPACK |
|
Reduce a matrix to upper Hessenberg form (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Singular value decomposition by the Jacobi method, for high relative accuracy (LAPACK |
|
Singular value decomposition by the Jacobi method, for high relative accuracy (LAPACK |
|
Solve an overdetermined or underdetermined system by QR or LQ factorization (LAPACK |
|
Solve an overdetermined or underdetermined system by QR or LQ factorization (LAPACK |
|
Solve an overdetermined or underdetermined system by QR or LQ factorization (LAPACK |
|
Solve an overdetermined or underdetermined system by QR or LQ factorization (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a least-squares problem by divide-and-conquer SVD (LAPACK |
|
Solve a least-squares problem by divide-and-conquer SVD (LAPACK |
|
Solve a least-squares problem by divide-and-conquer SVD (LAPACK |
|
Solve a least-squares problem by divide-and-conquer SVD (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a least-squares problem by singular value decomposition (LAPACK |
|
Solve a least-squares problem by singular value decomposition (LAPACK |
|
Solve a least-squares problem by singular value decomposition (LAPACK |
|
Solve a least-squares problem by singular value decomposition (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a least-squares problem by complete orthogonal factorization (LAPACK |
|
Solve a least-squares problem by complete orthogonal factorization (LAPACK |
|
Solve a least-squares problem by complete orthogonal factorization (LAPACK |
|
Solve a least-squares problem by complete orthogonal factorization (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute a QR factorization with column pivoting (LAPACK |
|
Compute a QR factorization with column pivoting (LAPACK |
|
Compute a QR factorization with column pivoting (LAPACK |
|
Compute a QR factorization with column pivoting (LAPACK |
|
Compute a QR factorization (LAPACK |
|
Compute a QR factorization (LAPACK |
|
Compute a QR factorization (LAPACK |
|
Compute a QR factorization (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute a QR factorization whose |
|
Compute a QR factorization whose |
|
Compute a QR factorization whose |
|
Compute a QR factorization whose |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute an RQ factorization |
|
Compute an RQ factorization |
|
Compute an RQ factorization |
|
Compute an RQ factorization |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Compute the singular value decomposition |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Compute the LU factorization |
|
Compute the LU factorization |
|
Compute the LU factorization |
|
Compute the LU factorization |
|
Compute the LU factorization with complete pivoting (LAPACK |
|
Compute the LU factorization with complete pivoting (LAPACK |
|
Compute the LU factorization with complete pivoting (LAPACK |
|
Compute the LU factorization with complete pivoting (LAPACK |
|
Invert a matrix from its |
|
Invert a matrix from its |
|
Invert a matrix from its |
|
Invert a matrix from its |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a system already factorized by |
|
Solve a system already factorized by |
|
Solve a system already factorized by |
|
Solve a system already factorized by |
|
Solve a system factorized by |
|
Solve a system factorized by |
|
Solve a system factorized by |
|
Solve a system factorized by |
|
Compute the generalized Schur factorization of a matrix pair (LAPACK |
|
Compute the generalized Schur factorization of a matrix pair (LAPACK |
|
Compute the generalized Schur factorization of a matrix pair (LAPACK |
|
Compute the generalized Schur factorization of a matrix pair (LAPACK |
|
Solve the generalized eigenproblem |
|
Solve the generalized eigenproblem |
|
Solve the generalized eigenproblem |
|
Solve the generalized eigenproblem |
|
Solve an equality-constrained least squares problem (LAPACK |
|
Solve an equality-constrained least squares problem (LAPACK |
|
Solve an equality-constrained least squares problem (LAPACK |
|
Solve an equality-constrained least squares problem (LAPACK |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve a tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a tridiagonal system with condition estimation and error bounds (LAPACK |
|
Eigenvalues and eigenvectors of a Hermitian band matrix, by divide and conquer (LAPACK |
|
Eigenvalues and eigenvectors of a Hermitian band matrix, by divide and conquer (LAPACK |
|
Selected eigenvalues and eigenvectors of a Hermitian band matrix (LAPACK |
|
Selected eigenvalues and eigenvectors of a Hermitian band matrix (LAPACK |
|
Estimate the reciprocal condition number of a Hermitian indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Estimate the reciprocal condition number of a Hermitian indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Compute scale factors that equilibrate a Hermitian matrix (LAPACK |
|
Compute scale factors that equilibrate a Hermitian matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a Hermitian matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a Hermitian matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute the eigenvalues and optionally the eigenvectors of a Hermitian matrix by divide-and-conquer (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a Hermitian matrix by divide-and-conquer (LAPACK |
|
Query the optimal workspace sizes for |
|
Query the optimal workspace sizes for |
|
Compute selected eigenvalues and optionally eigenvectors of a Hermitian matrix by the MRRR algorithm (LAPACK |
|
Compute selected eigenvalues and optionally eigenvectors of a Hermitian matrix by the MRRR algorithm (LAPACK |
|
Query the optimal workspace sizes for |
|
Query the optimal workspace sizes for |
|
Compute selected eigenvalues and optionally eigenvectors of a Hermitian matrix (LAPACK |
|
Compute selected eigenvalues and optionally eigenvectors of a Hermitian matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Reduce a generalized Hermitian-definite problem to standard form (LAPACK |
|
Reduce a generalized Hermitian-definite problem to standard form (LAPACK |
|
Solve the generalized Hermitian-definite eigenproblem (LAPACK |
|
Solve the generalized Hermitian-definite eigenproblem (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve the generalized Hermitian-definite eigenproblem by divide-and-conquer (LAPACK |
|
Solve the generalized Hermitian-definite eigenproblem by divide-and-conquer (LAPACK |
|
Compute selected eigenvalues of the generalized Hermitian-definite problem (LAPACK |
|
Compute selected eigenvalues of the generalized Hermitian-definite problem (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve |
|
Solve |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a Hermitian indefinite system with condition estimation and error bounds (LAPACK |
|
Solve a Hermitian indefinite system with condition estimation and error bounds (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Reduce a Hermitian matrix to real symmetric tridiagonal form by a unitary similarity transformation (LAPACK |
|
Reduce a Hermitian matrix to real symmetric tridiagonal form by a unitary similarity transformation (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute the blocked Bunch-Kaufman factorization of a Hermitian matrix (LAPACK |
|
Compute the blocked Bunch-Kaufman factorization of a Hermitian matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Invert a Hermitian indefinite matrix from the factorization computed by |
|
Invert a Hermitian indefinite matrix from the factorization computed by |
|
Solve a Hermitian indefinite system using the factorization from |
|
Solve a Hermitian indefinite system using the factorization from |
|
Hermitian rank-k update of a matrix held in rectangular full packed (RFP) storage (LAPACK |
|
Hermitian rank-k update of a matrix held in rectangular full packed (RFP) storage (LAPACK |
|
Machine parameters for this precision (LAPACK |
|
Machine parameters for this precision (LAPACK |
|
Compute a norm of a banded matrix (LAPACK |
|
Compute a norm of a banded matrix (LAPACK |
|
Compute a norm of a banded matrix (LAPACK |
|
Compute a norm of a banded matrix (LAPACK |
|
Norm of a general matrix (LAPACK |
|
Norm of a general matrix (LAPACK |
|
Norm of a general matrix (LAPACK |
|
Norm of a general matrix (LAPACK |
|
Norm of a triangular or trapezoidal matrix (LAPACK |
|
Norm of a triangular or trapezoidal matrix (LAPACK |
|
Norm of a triangular or trapezoidal matrix (LAPACK |
|
Norm of a triangular or trapezoidal matrix (LAPACK |
|
Apply an elementary reflector to a matrix (LAPACK |
|
Apply an elementary reflector to a matrix (LAPACK |
|
Apply an elementary reflector to a matrix (LAPACK |
|
Apply an elementary reflector to a matrix (LAPACK |
|
Generate an elementary reflector (LAPACK |
|
Generate an elementary reflector (LAPACK |
|
Generate an elementary reflector (LAPACK |
|
Generate an elementary reflector (LAPACK |
|
Generate a Givens rotation (LAPACK |
|
Generate a Givens rotation (LAPACK |
|
Generate a Givens rotation (LAPACK |
|
Generate a Givens rotation (LAPACK |
|
Compute one root of the secular equation of a rank-one modified diagonal matrix (LAPACK |
|
Compute one root of the secular equation of a rank-one modified diagonal matrix (LAPACK |
|
Apply a sequence of row interchanges to a matrix (LAPACK |
|
Apply a sequence of row interchanges to a matrix (LAPACK |
|
Apply a sequence of row interchanges to a matrix (LAPACK |
|
Apply a sequence of row interchanges to a matrix (LAPACK |
|
Multiply a triangular matrix by its own adjoint (LAPACK |
|
Multiply a triangular matrix by its own adjoint (LAPACK |
|
Multiply a triangular matrix by its own adjoint (LAPACK |
|
Multiply a triangular matrix by its own adjoint (LAPACK |
|
CS decomposition of a partitioned orthogonal matrix (LAPACK |
|
CS decomposition of a partitioned orthogonal matrix (LAPACK |
|
Query the workspace |
|
Query the workspace |
|
Generate the orthogonal/unitary matrix of a Hessenberg reduction (LAPACK |
|
Generate the orthogonal/unitary matrix of a Hessenberg reduction (LAPACK |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Solve a positive definite band system by Cholesky factorization (LAPACK |
|
Solve a positive definite band system by Cholesky factorization (LAPACK |
|
Solve a positive definite band system by Cholesky factorization (LAPACK |
|
Solve a positive definite band system by Cholesky factorization (LAPACK |
|
Compute the Cholesky factorization of a positive definite band matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite band matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite band matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite band matrix (LAPACK |
|
Solve a positive definite band system using a Cholesky factorization already computed by |
|
Solve a positive definite band system using a Cholesky factorization already computed by |
|
Solve a positive definite band system using a Cholesky factorization already computed by |
|
Solve a positive definite band system using a Cholesky factorization already computed by |
|
Compute the Cholesky factorization of a positive definite matrix in rectangular full packed (RFP) storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in rectangular full packed (RFP) storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in rectangular full packed (RFP) storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in rectangular full packed (RFP) storage (LAPACK |
|
Invert a positive definite matrix in rectangular full packed (RFP) storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in rectangular full packed (RFP) storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in rectangular full packed (RFP) storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in rectangular full packed (RFP) storage from its Cholesky factorization (LAPACK |
|
Solve a positive definite system in rectangular full packed (RFP) storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in rectangular full packed (RFP) storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in rectangular full packed (RFP) storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in rectangular full packed (RFP) storage using a Cholesky factorization already computed by |
|
Estimate the reciprocal condition number of a positive definite matrix from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix from its Cholesky factorization (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, blocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, blocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, blocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, blocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, unblocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, unblocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, unblocked (LAPACK |
|
Compute the pivoted Cholesky factorization of a positive semidefinite matrix, unblocked (LAPACK |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Compute the Cholesky factorization of a positive definite matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix (LAPACK |
|
Invert a positive definite matrix from the factorization computed by |
|
Invert a positive definite matrix from the factorization computed by |
|
Invert a positive definite matrix from the factorization computed by |
|
Invert a positive definite matrix from the factorization computed by |
|
Solve a positive definite system using the factorization from |
|
Solve a positive definite system using the factorization from |
|
Solve a positive definite system using the factorization from |
|
Solve a positive definite system using the factorization from |
|
Estimate the reciprocal condition number of a positive definite matrix in packed storage, from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix in packed storage, from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix in packed storage, from its Cholesky factorization (LAPACK |
|
Estimate the reciprocal condition number of a positive definite matrix in packed storage, from its Cholesky factorization (LAPACK |
|
Solve a positive definite system whose matrix is in packed storage, by Cholesky factorization (LAPACK |
|
Solve a positive definite system whose matrix is in packed storage, by Cholesky factorization (LAPACK |
|
Solve a positive definite system whose matrix is in packed storage, by Cholesky factorization (LAPACK |
|
Solve a positive definite system whose matrix is in packed storage, by Cholesky factorization (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in packed storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in packed storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in packed storage (LAPACK |
|
Compute the Cholesky factorization of a positive definite matrix in packed storage (LAPACK |
|
Invert a positive definite matrix in packed storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in packed storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in packed storage from its Cholesky factorization (LAPACK |
|
Invert a positive definite matrix in packed storage from its Cholesky factorization (LAPACK |
|
Solve a positive definite system in packed storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in packed storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in packed storage using a Cholesky factorization already computed by |
|
Solve a positive definite system in packed storage using a Cholesky factorization already computed by |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Solve a positive definite tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a positive definite tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a positive definite tridiagonal system with condition estimation and error bounds (LAPACK |
|
Solve a positive definite tridiagonal system with condition estimation and error bounds (LAPACK |
|
Compute the |
|
Compute the |
|
Compute the |
|
Compute the |
|
Solve a positive definite tridiagonal system using the factorization from |
|
Solve a positive definite tridiagonal system using the factorization from |
|
Solve a positive definite tridiagonal system using the factorization from |
|
Solve a positive definite tridiagonal system using the factorization from |
|
Compute the eigenvalues and optionally the eigenvectors of a positive definite tridiagonal matrix, to high relative accuracy (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a positive definite tridiagonal matrix, to high relative accuracy (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a positive definite tridiagonal matrix, to high relative accuracy (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a positive definite tridiagonal matrix, to high relative accuracy (LAPACK |
|
Apply a plane rotation to a pair of complex vectors (LAPACK |
|
Apply a plane rotation to a pair of complex vectors (LAPACK |
|
Eigenvalues and eigenvectors of a symmetric band matrix (LAPACK |
|
Eigenvalues and eigenvectors of a symmetric band matrix (LAPACK |
|
Eigenvalues and eigenvectors of a symmetric band matrix, by divide and conquer (LAPACK |
|
Eigenvalues and eigenvectors of a symmetric band matrix, by divide and conquer (LAPACK |
|
Selected eigenvalues and eigenvectors of a symmetric band matrix (LAPACK |
|
Selected eigenvalues and eigenvectors of a symmetric band matrix (LAPACK |
|
Symmetric rank-k update of a matrix held in rectangular full packed (RFP) storage (LAPACK |
|
Symmetric rank-k update of a matrix held in rectangular full packed (RFP) storage (LAPACK |
|
Compute selected eigenvalues of a symmetric tridiagonal matrix by bisection (LAPACK |
|
Compute selected eigenvalues of a symmetric tridiagonal matrix by bisection (LAPACK |
|
Compute eigenvectors of a symmetric tridiagonal matrix by inverse iteration, for eigenvalues supplied by |
|
Compute eigenvectors of a symmetric tridiagonal matrix by inverse iteration, for eigenvalues supplied by |
|
Compute selected eigenvalues and optionally eigenvectors of a symmetric tridiagonal matrix by the MRRR algorithm (LAPACK |
|
Compute selected eigenvalues and optionally eigenvectors of a symmetric tridiagonal matrix by the MRRR algorithm (LAPACK |
|
Query the optimal lwork and liwork for |
|
Query the optimal lwork and liwork for |
|
Compute all eigenvalues of a symmetric tridiagonal matrix by the Pal-Walker- Kahan QL/QR variant, without eigenvectors (LAPACK |
|
Compute all eigenvalues of a symmetric tridiagonal matrix by the Pal-Walker- Kahan QL/QR variant, without eigenvectors (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a symmetric tridiagonal matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a symmetric tridiagonal matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a symmetric tridiagonal matrix by divide-and-conquer (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a symmetric tridiagonal matrix by divide-and-conquer (LAPACK |
|
Estimate the reciprocal condition number of a symmetric indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Estimate the reciprocal condition number of a symmetric indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Estimate the reciprocal condition number of a symmetric indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Estimate the reciprocal condition number of a symmetric indefinite matrix from its Bunch-Kaufman factorization (LAPACK |
|
Convert the Bunch-Kaufman factorization between its packed and its expanded storage (LAPACK |
|
Convert the Bunch-Kaufman factorization between its packed and its expanded storage (LAPACK |
|
Convert the Bunch-Kaufman factorization between its packed and its expanded storage (LAPACK |
|
Convert the Bunch-Kaufman factorization between its packed and its expanded storage (LAPACK |
|
Compute scale factors that equilibrate a symmetric matrix (LAPACK |
|
Compute scale factors that equilibrate a symmetric matrix (LAPACK |
|
Compute scale factors that equilibrate a symmetric matrix (LAPACK |
|
Compute scale factors that equilibrate a symmetric matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a real symmetric matrix (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a real symmetric matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute the eigenvalues and optionally the eigenvectors of a real symmetric matrix by divide-and-conquer (LAPACK |
|
Compute the eigenvalues and optionally the eigenvectors of a real symmetric matrix by divide-and-conquer (LAPACK |
|
Query the optimal workspace sizes for |
|
Query the optimal workspace sizes for |
|
Compute selected eigenvalues and optionally eigenvectors of a real symmetric matrix by the MRRR algorithm (LAPACK |
|
Compute selected eigenvalues and optionally eigenvectors of a real symmetric matrix by the MRRR algorithm (LAPACK |
|
Query the optimal workspace sizes for |
|
Query the optimal workspace sizes for |
|
Compute selected eigenvalues and optionally eigenvectors of a real symmetric matrix (LAPACK |
|
Compute selected eigenvalues and optionally eigenvectors of a real symmetric matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Reduce a generalized symmetric-definite problem to standard form (LAPACK |
|
Reduce a generalized symmetric-definite problem to standard form (LAPACK |
|
Solve the generalized symmetric-definite eigenproblem (LAPACK |
|
Solve the generalized symmetric-definite eigenproblem (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve the generalized symmetric-definite eigenproblem by divide-and-conquer (LAPACK |
|
Solve the generalized symmetric-definite eigenproblem by divide-and-conquer (LAPACK |
|
Compute selected eigenvalues of the generalized symmetric-definite problem (LAPACK |
|
Compute selected eigenvalues of the generalized symmetric-definite problem (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve |
|
Solve |
|
Solve |
|
Solve |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Solve a symmetric indefinite system with condition estimation and error bounds (LAPACK |
|
Solve a symmetric indefinite system with condition estimation and error bounds (LAPACK |
|
Solve a symmetric indefinite system with condition estimation and error bounds (LAPACK |
|
Solve a symmetric indefinite system with condition estimation and error bounds (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute the unblocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the unblocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the unblocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the unblocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Reduce a real symmetric matrix to real symmetric tridiagonal form by an orthogonal similarity transformation (LAPACK |
|
Reduce a real symmetric matrix to real symmetric tridiagonal form by an orthogonal similarity transformation (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Compute the blocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the blocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the blocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Compute the blocked Bunch-Kaufman factorization of a symmetric matrix (LAPACK |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Query the optimal lwork for |
|
Invert a symmetric indefinite matrix from the factorization computed by |
|
Invert a symmetric indefinite matrix from the factorization computed by |
|
Invert a symmetric indefinite matrix from the factorization computed by |
|
Invert a symmetric indefinite matrix from the factorization computed by |
|
Solve a symmetric indefinite system using the factorization from |
|
Solve a symmetric indefinite system using the factorization from |
|
Solve a symmetric indefinite system using the factorization from |
|
Solve a symmetric indefinite system using the factorization from |
|
Solve a triangular band system (LAPACK |
|
Solve a triangular band system (LAPACK |
|
Solve a triangular band system (LAPACK |
|
Solve a triangular band system (LAPACK |
|
Solve a triangular system whose matrix is in rectangular full packed (RFP) storage (LAPACK |
|
Solve a triangular system whose matrix is in rectangular full packed (RFP) storage (LAPACK |
|
Solve a triangular system whose matrix is in rectangular full packed (RFP) storage (LAPACK |
|
Solve a triangular system whose matrix is in rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to packed (TP) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to packed (TP) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to packed (TP) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to packed (TP) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to full (TR) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to full (TR) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to full (TR) storage (LAPACK |
|
Convert a triangle from rectangular full packed (RFP) to full (TR) storage (LAPACK |
|
Reorder a generalized Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a generalized Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a generalized Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a generalized Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a generalized Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a generalized Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a generalized Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a generalized Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Query the workspace |
|
Query the workspace |
|
Query the workspace |
|
Query the workspace |
|
Solve the generalized Sylvester equations (LAPACK |
|
Solve the generalized Sylvester equations (LAPACK |
|
Convert a triangle from packed (TP) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from packed (TP) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from packed (TP) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from packed (TP) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from packed (TP) to full (TR) storage (LAPACK |
|
Convert a triangle from packed (TP) to full (TR) storage (LAPACK |
|
Convert a triangle from packed (TP) to full (TR) storage (LAPACK |
|
Convert a triangle from packed (TP) to full (TR) storage (LAPACK |
|
Estimate the reciprocal condition number of a triangular matrix (LAPACK |
|
Estimate the reciprocal condition number of a triangular matrix (LAPACK |
|
Estimate the reciprocal condition number of a triangular matrix (LAPACK |
|
Estimate the reciprocal condition number of a triangular matrix (LAPACK |
|
Reorder a Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a Schur decomposition by moving one diagonal block (LAPACK |
|
Reorder a Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Reorder a Schur decomposition to gather selected eigenvalues into a leading cluster (LAPACK |
|
Query the workspace |
|
Query the workspace |
|
Query the workspace |
|
Query the workspace |
|
Solve the Sylvester equation |
|
Solve the Sylvester equation |
|
Solve the Sylvester equation |
|
Solve the Sylvester equation |
|
Invert a triangular matrix (LAPACK |
|
Invert a triangular matrix (LAPACK |
|
Invert a triangular matrix (LAPACK |
|
Invert a triangular matrix (LAPACK |
|
Solve a triangular system (LAPACK |
|
Solve a triangular system (LAPACK |
|
Solve a triangular system (LAPACK |
|
Solve a triangular system (LAPACK |
|
Convert a triangle from full (TR) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from full (TR) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from full (TR) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from full (TR) to rectangular full packed (RFP) storage (LAPACK |
|
Convert a triangle from full (TR) to packed (TP) storage (LAPACK |
|
Convert a triangle from full (TR) to packed (TP) storage (LAPACK |
|
Convert a triangle from full (TR) to packed (TP) storage (LAPACK |
|
Convert a triangle from full (TR) to packed (TP) storage (LAPACK |
|
Reduce an upper trapezoidal matrix to upper triangular form (LAPACK |
|
Reduce an upper trapezoidal matrix to upper triangular form (LAPACK |
|
Reduce an upper trapezoidal matrix to upper triangular form (LAPACK |
|
Reduce an upper trapezoidal matrix to upper triangular form (LAPACK |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Generate the orthogonal/unitary matrix of a Hessenberg reduction (LAPACK |
|
Generate the orthogonal/unitary matrix of a Hessenberg reduction (LAPACK |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Generate the orthogonal/unitary factor |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Blocked QR factorization in the compact WY representation (LAPACK |
|
Blocked QR factorization in the compact WY representation (LAPACK |
|
Blocked QR factorization in the compact WY representation (LAPACK |
|
Blocked QR factorization in the compact WY representation (LAPACK |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Compute the LU factorization of a tridiagonal matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a tridiagonal matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a tridiagonal matrix with partial pivoting (LAPACK |
|
Compute the LU factorization of a tridiagonal matrix with partial pivoting (LAPACK |
|
Solve a tridiagonal system using the factorization from |
|
Solve a tridiagonal system using the factorization from |
|
Solve a tridiagonal system using the factorization from |
|
Solve a tridiagonal system using the factorization from |
|
Estimate the reciprocal condition number of a tridiagonal matrix from its |
|
Estimate the reciprocal condition number of a tridiagonal matrix from its |
|
Estimate the reciprocal condition number of a tridiagonal matrix from its |
|
Estimate the reciprocal condition number of a tridiagonal matrix from its |
|
Blocked QR factorization of a triangular-pentagonal matrix (LAPACK |
|
Blocked QR factorization of a triangular-pentagonal matrix (LAPACK |
|
Blocked QR factorization of a triangular-pentagonal matrix (LAPACK |
|
Blocked QR factorization of a triangular-pentagonal matrix (LAPACK |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
CS decomposition of a partitioned unitary matrix (LAPACK |
|
CS decomposition of a partitioned unitary matrix (LAPACK |
|
Query the workspace |
|
Query the workspace |
|
Multiply a matrix by the |
|
Multiply a matrix by the |
|
Query the optimal workspace for |
|
Query the optimal workspace for |
|
Version of the LAPACK library this module is linked against (LAPACK |